pub struct ListConversationsOptions {
pub conversation_type: Option<ConversationType>,
pub limit: i64,
pub created_after_ns: i64,
pub created_before_ns: i64,
pub last_activity_after_ns: i64,
pub last_activity_before_ns: i64,
pub consent_states: Vec<ConsentState>,
pub order_by: ConversationOrderBy,
pub include_duplicate_dms: bool,
}Expand description
Options for listing conversations.
Fields
conversation_type: Option<ConversationType>Filter by conversation type. None = all.
limit: i64Maximum number of conversations.
created_after_ns: i64Only conversations created after this timestamp (ns).
created_before_ns: i64Only conversations created before this timestamp (ns).
last_activity_after_ns: i64Only conversations with last activity after this timestamp (ns).
last_activity_before_ns: i64Only conversations with last activity before this timestamp (ns).
consent_states: Vec<ConsentState>Filter by consent states. Empty = all.
order_by: ConversationOrderBySort order for results.
include_duplicate_dms: boolWhether to include duplicate DMs.